pub struct GeneratorConfig { /* private fields */ }Expand description
Main configuration entry point.
Implementations
Sourceimpl GeneratorConfig
impl GeneratorConfig
Sourcepub fn new(
fragment_generators: impl IntoIterator<Item = Box<dyn FragmentGenerator>>,
) -> Self
pub fn new( fragment_generators: impl IntoIterator<Item = Box<dyn FragmentGenerator>>, ) -> Self
Constructs a new configuration instance with only the specified fragment generators.
The common fragment generators are not included. This constructor is merely used for testing purpose.
Sourcepub fn default_with_custom_generators(
custom_generators: impl IntoIterator<Item = Box<dyn FragmentGenerator>>,
) -> Self
pub fn default_with_custom_generators( custom_generators: impl IntoIterator<Item = Box<dyn FragmentGenerator>>, ) -> Self
Constructs a new configuration instance with the common fragment generators included and some additional custom generators like SerdeImplGenerator to enable the serialization features.